Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6684)

Unified Diff: chrome/browser/net/chrome_url_request_context.cc

Issue 5903005: The URLRequestContext for off-the-record mode should... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/net/chrome_url_request_context.cc
===================================================================
--- chrome/browser/net/chrome_url_request_context.cc (revision 69414)
+++ chrome/browser/net/chrome_url_request_context.cc (working copy)
@@ -402,9 +402,10 @@
IOThread::Globals* io_thread_globals = io_thread()->globals();
// Share the same proxy service, host resolver, and http_auth_handler_factory
// as the original profile.
context->set_host_resolver(original_context->host_resolver());
+ context->set_cert_verifier(original_context->cert_verifier());
wtc 2010/12/17 01:11:42 agl: I noticed that you don't copy original_contex
context->set_proxy_service(original_context->proxy_service());
context->set_http_auth_handler_factory(
@@ -402,9 +402,10 @@
IOThread::Globals* io_thread_globals = io_thread()->globals();
- // Share the same proxy service, host resolver, and http_auth_handler_factory
- // as the original profile.
+ // Share the same proxy service, host resolver, cert verifier,
+ // and http_auth_handler_factory as the original profile.
context->set_host_resolver(original_context->host_resolver());
original_context->http_auth_handler_factory());
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698